(release-notes)=

# Release notes


## Version 0.15.0

```{include} /release-notes/0.15.0.md
```

## Version 0.14.0

```{include} /release-notes/0.14.1.md
```
```{include} /release-notes/0.14.0.md
```

## Version 0.13.0
```{include} /release-notes/0.13.5.md
```
```{include} /release-notes/0.13.4.md
```
```{include} /release-notes/0.13.3.md
```
```{include} /release-notes/0.13.2.md
```
```{include} /release-notes/0.13.1.md
```
```{include} /release-notes/0.13.0.md
```

## Version 0.12.0
```{include} /release-notes/0.12.7.md
```
```{include} /release-notes/0.12.6.md
```
```{include} /release-notes/0.12.5.md
```
```{include} /release-notes/0.12.4.md
```
```{include} /release-notes/0.12.3.md
```
```{include} /release-notes/0.12.2.md
```
```{include} /release-notes/0.12.1.md
```
```{include} /release-notes/0.12.0.md
```

## Version 0.11.0
```{include} /release-notes/0.11.1.md
```
```{include} /release-notes/0.11.0.md
```

## Version 0.10.0
```{include} /release-notes/0.10.11.md
```
```{include} /release-notes/0.10.10.md
```
```{include} /release-notes/0.10.9.md
```
```{include} /release-notes/0.10.8.md
```
```{include} /release-notes/0.10.7.md
```
```{include} /release-notes/0.10.6.md
```
```{include} /release-notes/0.10.5.md
```
```{include} /release-notes/0.10.4.md
```
```{include} /release-notes/0.10.3.md
```
```{include} /release-notes/0.10.2.md
```
```{include} /release-notes/0.10.1.md
```
```{include} /release-notes/0.10.0.md
```

## Version 0.9.0
```{include} /release-notes/0.9.6.md
```
```{include} /release-notes/0.9.5.md
```
```{include} /release-notes/0.9.4.md
```
```{include} /release-notes/0.9.3.md
```
```{include} /release-notes/0.9.2.md
```
```{include} /release-notes/0.9.1.md
```
```{include} /release-notes/0.9.0.md
```

## Version 0.8.0
```{include} /release-notes/0.8.1.md
```
```{include} /release-notes/0.8.0.md
```
